# == Class: thunderbird::lightning::gdata
#
# This module provides a class to install or remove the Google data provider
# for Thunderbird's lightning plugin.
#
# === Parameters
#
# [*ensure*]
#   Ensure if present, installed, absent, purged, held, latest, or a specific
#   version.
#
#   Default: present
#
# === Examples
#
# To install the Google data provider for lightning for Thunderbird:
#
#   class { thunderbird::lightning::gdata: ensure => 'present' }
#
# To remove the Google data provider for lightning for Thunderbird:
#
#  class { thunderbird::lightning::gdata: ensure => 'absent' }
#
# === Copyright
#
# Copyright (C) 2013 Jeffrey Goettsch <jgoettsch@gmail.com>.
#
# This file is part of jgoettsch-thunderbird.
#
# jgoettsch-thunderbird is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# jgoettsch-thunderbird is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with jgoettsch-thunderbird.  If not, see <http://www.gnu.org/licenses/>.
#
class thunderbird::lightning::gdata (
  $ensure = 'present',
) inherits thunderbird::lightning::gdata::params {

  package { 'thunderbird::lightning::gdata':
    name    => $package_name,
    ensure  => $ensure,
    require => [
      Package['thunderbird'],
      Package['thunderbird-lightning'],
    ],
  }
}
